@@ -1,6 +1,6 @@
 import shutil
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Set
 from hatchling.builders.hooks.plugin.interface import BuildHookInterface
 from hatch_polylith_bricks.polylith import parsing, repo, toml
 from hatch_polylith_bricks.polylith.hatch import core
@@ -24,6 +24,21 @@ def filtered_bricks(data: dict, version: str) -> dict:
         return filter_dev_mode_bricks(data, bricks)
     return bricks
 
+def collect_configured_exclude_patterns(data: dict, target_name: str) -> set:
+    entry = data.get('tool', {}).get('hatch', {}).get('build', {})
+    target = entry.get('targets', {}).get(target_name, {})
+    exclude = target.get('exclude', [])
+    return set(exclude)
+
+def copy_bricks(bricks: dict, work_dir: Path, exclude_patterns: Set[str]) -> List[Path]:
+    return [parsing.copy_brick(source, brick, work_dir, exclude_patterns) for source, brick in bricks.items()]
+
+def rewrite_modules(paths: List[Path], ns: str, top_ns: str) -> None:
+    for path in paths:
+        rewritten_bricks = parsing.rewrite_modules(path, ns, top_ns)
+        for item in rewritten_bricks:
+            print(f'Updated {item} with new top namespace for local imports.')
+
 class PolylithBricksHook(BuildHookInterface):
     PLUGIN_NAME = 'polylith-bricks'
 
@@ -36,18 +51,19 @@ class PolylithBricksHook(BuildHookInterface):
         found_bricks = {k: v for k, v in bricks.items() if Path(f'{root}/{k}').exists()}
         if not bricks or not found_bricks:
             return
+        ns = parsing.parse_brick_namespace_from_path(bricks)
         top_ns = core.get_top_namespace(data, self.config)
         work_dir = core.get_work_dir(self.config)
-        if not top_ns:
+        exclude_patterns = collect_configured_exclude_patterns(data, self.target_name)
+        if not top_ns and (not exclude_patterns):
             build_data[include_key] = bricks
             return
-        ns = parsing.parse_brick_namespace_from_path(bricks)
-        for source, brick in bricks.items():
-            path = parsing.copy_brick(source, brick, work_dir)
-            rewritten_bricks = parsing.rewrite_modules(path, ns, top_ns)
-            for item in rewritten_bricks:
-                print(f'Updated {item} with new top namespace for local imports.')
         key = work_dir.as_posix()
+        paths = copy_bricks(bricks, work_dir, exclude_patterns)
+        if not top_ns:
+            build_data[include_key] = {f'{key}/{ns}': ns}
+            return
+        rewrite_modules(paths, ns, top_ns)
         build_data[include_key][key] = top_ns
 
     def finalize(self, *args, **kwargs) -> None:
