@@ -1,6 +1,9 @@
+from functools import lru_cache
 from pathlib import Path
 from typing import Union
 
+import tomlkit
+
 workspace_file = "workspace.toml"
 root_file = ".git"
 default_toml = "pyproject.toml"
@@ -12,6 +15,41 @@ projects_dir = "projects"
 development_dir = "development"
 
 
+def load_content(fullpath: Path) -> tomlkit.TOMLDocument:
+    content = fullpath.read_text()
+
+    return tomlkit.loads(content)
+
+
+@lru_cache
+def load_root_project_config(path: Path) -> tomlkit.TOMLDocument:
+    fullpath = path / default_toml
+
+    if not fullpath.exists():
+        return tomlkit.TOMLDocument()
+
+    return load_content(fullpath)
+
+
+def has_workspace_config(data: tomlkit.TOMLDocument) -> bool:
+    ns = data.get("tool", {}).get("polylith", {}).get("namespace")
+
+    return True if ns else False
+
+
+@lru_cache
+def load_workspace_config(path: Path) -> tomlkit.TOMLDocument:
+    fullpath = path / workspace_file
+
+    if fullpath.exists():
+        content = load_content(fullpath)
+
+        if has_workspace_config(content):
+            return content
+
+    return load_root_project_config(path)
+
+
 def is_drive_root(cwd: Path) -> bool:
     return cwd == Path(cwd.root) or cwd == cwd.parent
 
@@ -22,6 +60,12 @@ def is_repo_root(cwd: Path) -> bool:
     return fullpath.exists()
 
 
+def is_python_workspace_root(path: Path) -> bool:
+    data = load_root_project_config(path)
+
+    return has_workspace_config(data)
+
+
 def find_upwards(cwd: Path, name: str) -> Union[Path, None]:
     if is_drive_root(cwd):
         return None
@@ -29,7 +73,10 @@ def find_upwards(cwd: Path, name: str) -> Union[Path, None]:
     fullpath = cwd / name
 
     if fullpath.exists():
-        return fullpath
+        if name == workspace_file:
+            return fullpath
+
+        return fullpath if is_python_workspace_root(cwd) else None
 
     if is_repo_root(cwd):
         return None
@@ -45,9 +92,13 @@ def find_upwards_dir(cwd: Path, name: str) -> Union[Path, None]:
 
 def find_workspace_root(cwd: Path) -> Union[Path, None]:
     workspace_root = find_upwards_dir(cwd, workspace_file)
+
     if workspace_root:
         return workspace_root
-    return find_upwards_dir(cwd, root_file)
+
+    repo_root = find_upwards_dir(cwd, root_file)
+
+    return repo_root or find_upwards_dir(cwd, default_toml)
 
 
 def get_workspace_root(cwd: Path) -> Path:
@@ -55,7 +106,7 @@ def get_workspace_root(cwd: Path) -> Path:
 
     if not root:
         raise ValueError(
-            "Didn't find the workspace root. Expected to find a workspace.toml or .git file."
+            "Didn't find the workspace root. Expected to find a workspace.toml or pyproject.toml with Workspace config."
         )
 
     return root
